==> boxw-0.0.35.tar.gz: lib/src/box.dart <==
part of '../boxw.dart';

class BoxWInput extends StatelessWidget {
  const BoxWInput({
    super.key,
    this.title = '',
    this.onChanged,
    this.initial,
    this.controller,
    this.validator,
    this.leadingButton,
    this.trailingButton,
    this.prefixIcon,
    this.suffixIcon,
    this.obscureText = false,
    this.keyboardType,
    this.margin = const EdgeInsets.symmetric(vertical: 8, horizontal: 12),
    this.padding = const EdgeInsets.symmetric(vertical: 12, horizontal: 12),
    this.style,
    this.titleStyle,
    this.titleAlign,
    this.floatingLabelAlignment,
    this.minLines = 1,
    this.maxLines,
    this.radius,
    this.borderColor,
    this.expands = false,
    this.enabled = true,
    this.autocorrect = false,
    this.errorText,
    this.maxLength,
    this.textAlign = TextAlign.center,
    this.readOnly = false,
  });

  final String title;
  final String? initial;
  final TextEditingController? controller;
  final Function(String)? onChanged;
  final String? Function(String?)? validator;

  /// Use `IconButton` in most cases.
  final Widget? leadingButton;
  final Widget? trailingButton;
  final Widget? prefixIcon;
  final Widget? suffixIcon;
  final bool obscureText;
  final TextInputType? keyboardType;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;
  final TextStyle? style;
  final TextAlign? titleAlign;
  final TextStyle? titleStyle;
  final FloatingLabelAlignment? floatingLabelAlignment;
  final int? minLines;
  final int? maxLines;
  final double? radius;
  final Color? borderColor;
  final bool expands;
  final bool enabled;
  final bool autocorrect;
  final String? errorText;
  final int? maxLength;
  final TextAlign textAlign;
  final bool readOnly;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: margin,
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          leadingButton ?? SizedBox.fromSize(),
          Expanded(
            child: TextFormField(
              enabled: enabled,
              readOnly: readOnly,
              style: style,
              decoration: InputDecoration(
                contentPadding: padding,
                border: OutlineInputBorder(
                  borderSide: BorderSide(
                    color: borderColor ??
                        BoxWConfig.borderColor ??
                        Theme.of(context).colorScheme.outline,
                  ),
                  borderRadius: BorderRadius.circular(
                    radius ?? BoxWConfig.radius,
                  ),
                ),
                label: Text(
                  title,
                  overflow: TextOverflow.ellipsis,
                  textAlign: titleAlign,
                  style: titleStyle,
                ),
                floatingLabelAlignment: floatingLabelAlignment,
                errorText: errorText,
                isDense: true,
                prefixIcon: prefixIcon,
                suffixIcon: suffixIcon,
              ),
              controller: controller,
              initialValue: controller == null ? initial : null,
              onChanged: onChanged,
              validator: validator,
              autovalidateMode: AutovalidateMode.onUserInteraction,
              obscureText: obscureText,
              keyboardType: keyboardType,
              minLines: minLines,
              maxLines: obscureText ? 1 : maxLines,
              expands: expands,
              autocorrect: autocorrect,
              maxLength: maxLength,
              textAlign: textAlign,
              onTapOutside: (event) {
                FocusManager.instance.primaryFocus?.unfocus();
              },
            ),
          ),
          trailingButton ?? SizedBox.fromSize(),
        ],
      ),
    );
  }
}

class BoxWDropdown<T> extends StatelessWidget {
  const BoxWDropdown({
    super.key,
    required this.items,
    required this.value,
    this.onChanged,
    this.selectedItemBuilder,
    this.title,
    this.borderColor,
    this.radius,
    this.titleStyle,
    this.padding = const EdgeInsets.symmetric(vertical: 8, horizontal: 12),
  });

  final String? title;
  final T value;
  final List<DropdownMenuItem<T>> items;
  final void Function(T? value)? onChanged;
  final List<Widget> Function(BuildContext)? selectedItemBuilder;
  final TextStyle? titleStyle;
  final double? radius;
  final Color? borderColor;
  final EdgeInsetsGeometry padding;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: padding,
      child: DropdownButtonFormField<T>(
        decoration: InputDecoration(
          isDense: true,
          border: OutlineInputBorder(
            borderSide: BorderSide(
              color: borderColor ??
                  BoxWConfig.borderColor ??
                  Theme.of(context).colorScheme.outline,
            ),
            borderRadius: BorderRadius.circular(radius ?? BoxWConfig.radius),
          ),
          label: title == null ? null : Text(title!, style: titleStyle),
        ),
        borderRadius: BorderRadius.circular(radius ?? BoxWConfig.radius),
        padding: EdgeInsets.zero,
        value: value,
        items: items,
        selectedItemBuilder: selectedItemBuilder,
        onChanged: onChanged,
        menuMaxHeight: MediaQuery.of(context).size.height * 3 / 4,
      ),
    );
  }
}

class BoxWButton extends StatelessWidget {
  const BoxWButton({
    super.key,
    required this.child,
    this.onPressed,
    this.backgroundColor,
    this.borderColor,
    this.radius,
    this.width,
    this.height,
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.padding = const EdgeInsets.symmetric(vertical: 10, horizontal: 4),
  });

  final Widget child;
  final Color? backgroundColor;
  final Color? borderColor;
  final VoidCallback? onPressed;
  final double? radius;
  final double? width;
  final double? height;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: margin,
      width: width ?? double.infinity,
      height: height,
      child: ElevatedButton(
        onPressed: onPressed,
        style: ElevatedButton.styleFrom(
          backgroundColor: backgroundColor,
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(radius ?? BoxWConfig.radius),
            side: BorderSide(
              color: borderColor ??
                  BoxWConfig.borderColor ??
                  Theme.of(context).colorScheme.outline,
            ),
          ),
        ),
        child: Padding(
          padding: padding,
          child: child,
        ),
      ),
    );
  }
}

class BoxWOutlinedButton extends StatelessWidget {
  const BoxWOutlinedButton({
    super.key,
    required this.child,
    this.onPressed,
    this.backgroundColor,
    this.borderColor,
    this.radius,
    this.width,
    this.height,
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.padding = const EdgeInsets.symmetric(vertical: 10, horizontal: 4),
  });

  final Widget child;
  final Color? backgroundColor;
  final Color? borderColor;
  final VoidCallback? onPressed;
  final double? radius;
  final double? width;
  final double? height;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: margin,
      width: width ?? double.infinity,
      height: height,
      child: OutlinedButton(
        onPressed: onPressed,
        style: OutlinedButton.styleFrom(
          backgroundColor: backgroundColor,
          side: borderColor == null && BoxWConfig.borderColor == null
              ? null
              : BorderSide(
                  color: borderColor ??
                      BoxWConfig.borderColor ??
                      Theme.of(context).colorScheme.outline,
                ),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(radius ?? BoxWConfig.radius),
          ),
        ),
        child: Padding(
          padding: padding,
          child: child,
        ),
      ),
    );
  }
}

class BoxWTextButton extends StatelessWidget {
  const BoxWTextButton({
    super.key,
    required this.child,
    this.onPressed,
    this.backgroundColor,
    this.radius,
    this.width,
    this.height,
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.padding = const EdgeInsets.symmetric(vertical: 0, horizontal: 12),
  });

  final Widget child;
  final Color? backgroundColor;
  final double? radius;
  final VoidCallback? onPressed;
  final double? width;
  final double? height;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;

  @override
  Widget build(BuildContext context) {
    return BoxWRect(
      alignment: Alignment.center,
      margin: margin,
      padding: EdgeInsets.zero,
      width: width ?? double.infinity,
      height: height,
      backgroundColor: backgroundColor,
      radius: radius,
      child: TextButton(
        onPressed: onPressed,
        style: TextButton.styleFrom(
          backgroundColor: Colors.transparent,
          padding: padding,
        ),
        child: child,
      ),
    );
  }
}

class BoxWCard extends StatelessWidget {
  const BoxWCard({
    super.key,
    required this.child,
    this.margin,
    this.borderColor,
    this.backgroundColor,
    this.radius,
  });

  final Widget child;
  final EdgeInsetsGeometry? margin;
  final Color? borderColor;
  final Color? backgroundColor;
  final double? radius;

  @override
  Widget build(BuildContext context) {
    return Card(
      elevation: 0,
      color: backgroundColor ?? Theme.of(context).colorScheme.surfaceVariant,
      margin: margin,
      shape: RoundedRectangleBorder(
        side: BorderSide(
          color: borderColor ??
              BoxWConfig.borderColor ??
              Theme.of(context).colorScheme.outline,
        ),
        borderRadius:
            BorderRadius.all(Radius.circular(radius ?? BoxWConfig.radius)),
      ),
      child: child,
    );
  }
}

class BoxWIconTextButton extends StatelessWidget {
  const BoxWIconTextButton({
    super.key,
    required this.icon,
    required this.title,
    this.trailing,
    this.onPressed,
    this.titlePadding = const EdgeInsets.symmetric(horizontal: 12, vertical: 0),
    this.padding = const EdgeInsets.symmetric(horizontal: 4, vertical: 4),
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.isNavigateTrailing = false,
  });

  final Widget icon;
  final Widget title;
  final bool isNavigateTrailing;
  final Widget? trailing;
  final void Function()? onPressed;
  final EdgeInsetsGeometry titlePadding;
  final EdgeInsetsGeometry padding;
  final EdgeInsetsGeometry margin;

  @override
  Widget build(BuildContext context) {
    return BoxWTextButton(
      padding: padding,
      margin: margin,
      onPressed: onPressed,
      child: Row(
        children: [
          icon,
          Expanded(
            child: Padding(
              padding: titlePadding,
              child: title,
            ),
          ),
          trailing ??
              SizedBox(
                width: 30,
                child: isNavigateTrailing
                    ? const Icon(Icons.navigate_next_outlined)
                    : null,
              ),
        ],
      ),
    );
  }
}

class BoxWTextIcon extends StatelessWidget {
  const BoxWTextIcon({
    super.key,
    required this.icon,
    required this.title,
    this.trailing,
    this.onPressed,
    this.isNavigateTrailing = false,
    this.borderColor,
    this.backgroundColor,
    this.subTitle,
    this.titlePadding = const EdgeInsets.symmetric(horizontal: 16, vertical: 0),
    this.padding = const EdgeInsets.symmetric(horizontal: 16, vertical: 8),
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
  });

  final Widget icon;
  final Widget title;
  final EdgeInsetsGeometry titlePadding;
  final EdgeInsetsGeometry padding;
  final EdgeInsetsGeometry margin;
  final String? subTitle;
  final Color? borderColor;
  final Color? backgroundColor;
  final bool isNavigateTrailing;
  final Widget? trailing;
  final void Function()? onPressed;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: margin,
      child: InkWell(
        onTap: onPressed,
        borderRadius: BorderRadius.circular(12),
        child: BoxWRect(
          margin: EdgeInsets.zero,
          borderColor: borderColor,
          backgroundColor: backgroundColor,
          padding: padding,
          child: Row(
            children: [
              icon,
              Expanded(
                child: Padding(
                  padding: titlePadding,
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      title,
                      if (subTitle != null) ...[
                        const SizedBox(height: 3),
                        Text(
                          subTitle!,
                          textAlign: TextAlign.left,
                          style:
                              const TextStyle(fontSize: 12, color: Colors.grey),
                        ),
                      ]
                    ],
                  ),
                ),
              ),
              trailing ??
                  (isNavigateTrailing
                      ? const SizedBox(
                          width: 30, child: Icon(Icons.navigate_next_outlined))
                      : const SizedBox.shrink()),
            ],
          ),
        ),
      ),
    );
  }
}

==> boxw-0.0.36.tar.gz: lib/src/box.dart <==
part of '../boxw.dart';

class BoxWInput extends StatelessWidget {
  const BoxWInput({
    super.key,
    this.title = '',
    this.onChanged,
    this.initial,
    this.controller,
    this.validator,
    this.leadingButton,
    this.trailingButton,
    this.prefixIcon,
    this.suffixIcon,
    this.obscureText = false,
    this.keyboardType,
    this.margin = const EdgeInsets.symmetric(vertical: 8, horizontal: 12),
    this.padding = const EdgeInsets.symmetric(vertical: 12, horizontal: 12),
    this.style,
    this.titleStyle,
    this.titleAlign,
    this.floatingLabelAlignment,
    this.minLines = 1,
    this.maxLines,
    this.radius,
    this.borderColor,
    this.expands = false,
    this.enabled = true,
    this.autocorrect = false,
    this.errorText,
    this.maxLength,
    this.textAlign = TextAlign.center,
    this.readOnly = false,
  });

  final String title;
  final String? initial;
  final TextEditingController? controller;
  final Function(String)? onChanged;
  final String? Function(String?)? validator;

  /// Use `IconButton` in most cases.
  final Widget? leadingButton;
  final Widget? trailingButton;
  final Widget? prefixIcon;
  final Widget? suffixIcon;
  final bool obscureText;
  final TextInputType? keyboardType;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;
  final TextStyle? style;
  final TextAlign? titleAlign;
  final TextStyle? titleStyle;
  final FloatingLabelAlignment? floatingLabelAlignment;
  final int? minLines;
  final int? maxLines;
  final double? radius;
  final Color? borderColor;
  final bool expands;
  final bool enabled;
  final bool autocorrect;
  final String? errorText;
  final int? maxLength;
  final TextAlign textAlign;
  final bool readOnly;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: margin,
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          leadingButton ?? SizedBox.fromSize(),
          Expanded(
            child: TextFormField(
              enabled: enabled,
              readOnly: readOnly,
              style: style,
              decoration: InputDecoration(
                contentPadding: padding,
                border: OutlineInputBorder(
                  borderSide: BorderSide(
                    color: borderColor ??
                        BoxWConfig.borderColor ??
                        Theme.of(context).colorScheme.outline,
                  ),
                  borderRadius: BorderRadius.circular(
                    radius ?? BoxWConfig.radius,
                  ),
                ),
                label: Text(
                  title,
                  overflow: TextOverflow.ellipsis,
                  textAlign: titleAlign,
                  style: titleStyle,
                ),
                floatingLabelAlignment: floatingLabelAlignment,
                errorText: errorText,
                isDense: true,
                prefixIcon: prefixIcon,
                suffixIcon: suffixIcon,
              ),
              controller: controller,
              initialValue: controller == null ? initial : null,
              onChanged: onChanged,
              validator: validator,
              autovalidateMode: AutovalidateMode.onUserInteraction,
              obscureText: obscureText,
              keyboardType: keyboardType,
              minLines: minLines,
              maxLines: obscureText ? 1 : maxLines,
              expands: expands,
              autocorrect: autocorrect,
              maxLength: maxLength,
              textAlign: textAlign,
              onTapOutside: (event) {
                FocusManager.instance.primaryFocus?.unfocus();
              },
            ),
          ),
          trailingButton ?? SizedBox.fromSize(),
        ],
      ),
    );
  }
}

class BoxWDropdown<T> extends StatelessWidget {
  const BoxWDropdown({
    super.key,
    required this.items,
    required this.value,
    this.onChanged,
    this.selectedItemBuilder,
    this.title,
    this.borderColor,
    this.radius,
    this.titleStyle,
    this.padding = EdgeInsets.zero,
    this.margin = const EdgeInsets.symmetric(vertical: 8, horizontal: 12),
    this.isExpanded = false,
    this.dropdownColor,
  });

  final String? title;
  final T value;
  final List<DropdownMenuItem<T>> items;
  final void Function(T? value)? onChanged;
  final List<Widget> Function(BuildContext)? selectedItemBuilder;
  final TextStyle? titleStyle;
  final double? radius;
  final Color? borderColor;
  final EdgeInsetsGeometry padding;
  final EdgeInsetsGeometry margin;
  final bool isExpanded;
  final Color? dropdownColor;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: margin,
      child: DropdownButtonFormField<T>(
        isDense: true,
        decoration: InputDecoration(
          isDense: true,
          border: OutlineInputBorder(
            borderSide: BorderSide(
              color: borderColor ??
                  BoxWConfig.borderColor ??
                  Theme.of(context).colorScheme.outline,
            ),
            borderRadius: BorderRadius.circular(radius ?? BoxWConfig.radius),
          ),
          label: title == null ? null : Text(title!, style: titleStyle),
        ),
        borderRadius: BorderRadius.circular(radius ?? BoxWConfig.radius),
        padding: padding,
        value: value,
        items: items,
        selectedItemBuilder: selectedItemBuilder,
        onChanged: onChanged,
        menuMaxHeight: MediaQuery.of(context).size.height * 3 / 4,
        isExpanded: isExpanded,
        dropdownColor: dropdownColor,
      ),
    );
  }
}

class BoxWButton extends StatelessWidget {
  const BoxWButton({
    super.key,
    required this.child,
    this.onPressed,
    this.backgroundColor,
    this.borderColor,
    this.radius,
    this.width,
    this.height,
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.padding = const EdgeInsets.symmetric(vertical: 10, horizontal: 4),
  });

  final Widget child;
  final Color? backgroundColor;
  final Color? borderColor;
  final VoidCallback? onPressed;
  final double? radius;
  final double? width;
  final double? height;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: margin,
      width: width ?? double.infinity,
      height: height,
      child: ElevatedButton(
        onPressed: onPressed,
        style: ElevatedButton.styleFrom(
          backgroundColor: backgroundColor,
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(radius ?? BoxWConfig.radius),
            side: BorderSide(
              color: borderColor ??
                  BoxWConfig.borderColor ??
                  Theme.of(context).colorScheme.outline,
            ),
          ),
        ),
        child: Padding(
          padding: padding,
          child: child,
        ),
      ),
    );
  }
}

class BoxWOutlinedButton extends StatelessWidget {
  const BoxWOutlinedButton({
    super.key,
    required this.child,
    this.onPressed,
    this.backgroundColor,
    this.borderColor,
    this.radius,
    this.width,
    this.height,
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.padding = const EdgeInsets.symmetric(vertical: 10, horizontal: 4),
  });

  final Widget child;
  final Color? backgroundColor;
  final Color? borderColor;
  final VoidCallback? onPressed;
  final double? radius;
  final double? width;
  final double? height;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: margin,
      width: width ?? double.infinity,
      height: height,
      child: OutlinedButton(
        onPressed: onPressed,
        style: OutlinedButton.styleFrom(
          backgroundColor: backgroundColor,
          side: borderColor == null && BoxWConfig.borderColor == null
              ? null
              : BorderSide(
                  color: borderColor ??
                      BoxWConfig.borderColor ??
                      Theme.of(context).colorScheme.outline,
                ),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(radius ?? BoxWConfig.radius),
          ),
        ),
        child: Padding(
          padding: padding,
          child: child,
        ),
      ),
    );
  }
}

class BoxWTextButton extends StatelessWidget {
  const BoxWTextButton({
    super.key,
    required this.child,
    this.onPressed,
    this.backgroundColor,
    this.radius,
    this.width,
    this.height,
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.padding = const EdgeInsets.symmetric(vertical: 0, horizontal: 12),
  });

  final Widget child;
  final Color? backgroundColor;
  final double? radius;
  final VoidCallback? onPressed;
  final double? width;
  final double? height;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;

  @override
  Widget build(BuildContext context) {
    return BoxWRect(
      alignment: Alignment.center,
      margin: margin,
      padding: EdgeInsets.zero,
      width: width ?? double.infinity,
      height: height,
      backgroundColor: backgroundColor,
      radius: radius,
      child: TextButton(
        onPressed: onPressed,
        style: TextButton.styleFrom(
          backgroundColor: Colors.transparent,
          padding: padding,
        ),
        child: child,
      ),
    );
  }
}

class BoxWCard extends StatelessWidget {
  const BoxWCard({
    super.key,
    required this.child,
    this.margin,
    this.borderColor,
    this.backgroundColor,
    this.radius,
  });

  final Widget child;
  final EdgeInsetsGeometry? margin;
  final Color? borderColor;
  final Color? backgroundColor;
  final double? radius;

  @override
  Widget build(BuildContext context) {
    return Card(
      elevation: 0,
      color: backgroundColor ?? Theme.of(context).colorScheme.surfaceVariant,
      margin: margin,
      shape: RoundedRectangleBorder(
        side: BorderSide(
          color: borderColor ??
              BoxWConfig.borderColor ??
              Theme.of(context).colorScheme.outline,
        ),
        borderRadius:
            BorderRadius.all(Radius.circular(radius ?? BoxWConfig.radius)),
      ),
      child: child,
    );
  }
}

class BoxWIconTextButton extends StatelessWidget {
  const BoxWIconTextButton({
    super.key,
    required this.icon,
    required this.title,
    this.trailing,
    this.onPressed,
    this.titlePadding = const EdgeInsets.symmetric(horizontal: 12, vertical: 0),
    this.padding = const EdgeInsets.symmetric(horizontal: 4, vertical: 4),
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
    this.isNavigateTrailing = false,
  });

  final Widget icon;
  final Widget title;
  final bool isNavigateTrailing;
  final Widget? trailing;
  final void Function()? onPressed;
  final EdgeInsetsGeometry titlePadding;
  final EdgeInsetsGeometry padding;
  final EdgeInsetsGeometry margin;

  @override
  Widget build(BuildContext context) {
    return BoxWTextButton(
      padding: padding,
      margin: margin,
      onPressed: onPressed,
      child: Row(
        children: [
          icon,
          Expanded(
            child: Padding(
              padding: titlePadding,
              child: title,
            ),
          ),
          trailing ??
              SizedBox(
                width: 30,
                child: isNavigateTrailing
                    ? const Icon(Icons.navigate_next_outlined)
                    : null,
              ),
        ],
      ),
    );
  }
}

class BoxWTextIcon extends StatelessWidget {
  const BoxWTextIcon({
    super.key,
    required this.icon,
    required this.title,
    this.trailing,
    this.onPressed,
    this.isNavigateTrailing = false,
    this.borderColor,
    this.backgroundColor,
    this.subTitle,
    this.titlePadding = const EdgeInsets.symmetric(horizontal: 16, vertical: 0),
    this.padding = const EdgeInsets.symmetric(horizontal: 16, vertical: 8),
    this.margin = const EdgeInsets.symmetric(horizontal: 8, vertical: 4),
  });

  final Widget icon;
  final Widget title;
  final EdgeInsetsGeometry titlePadding;
  final EdgeInsetsGeometry padding;
  final EdgeInsetsGeometry margin;
  final String? subTitle;
  final Color? borderColor;
  final Color? backgroundColor;
  final bool isNavigateTrailing;
  final Widget? trailing;
  final void Function()? onPressed;

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: margin,
      child: InkWell(
        onTap: onPressed,
        borderRadius: BorderRadius.circular(12),
        child: BoxWRect(
          margin: EdgeInsets.zero,
          borderColor: borderColor,
          backgroundColor: backgroundColor,
          padding: padding,
          child: Row(
            children: [
              icon,
              Expanded(
                child: Padding(
                  padding: titlePadding,
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    mainAxisAlignment: MainAxisAlignment.center,
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      title,
                      if (subTitle != null) ...[
                        const SizedBox(height: 3),
                        Text(
                          subTitle!,
                          textAlign: TextAlign.left,
                          style:
                              const TextStyle(fontSize: 12, color: Colors.grey),
                        ),
                      ]
                    ],
                  ),
                ),
              ),
              trailing ??
                  (isNavigateTrailing
                      ? const SizedBox(
                          width: 30, child: Icon(Icons.navigate_next_outlined))
                      : const SizedBox.shrink()),
            ],
          ),
        ),
      ),
    );
  }
}
